"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createApolloClient = void 0;
var _apolloClient = _interopRequireDefault(require("apollo-client"));
var _apolloLink = require("apollo-link");
var _apolloLinkBatchHttp = require("apollo-link-batch-http");
var _InMemoryCache = require("@webiny/app/apollo-client/InMemoryCache");
var _plugins = require("@webiny/plugins");
var _ApolloDynamicLink = require("@webiny/app/plugins/ApolloDynamicLink");
var _ApolloCacheObjectIdPlugin = require("@webiny/app/plugins/ApolloCacheObjectIdPlugin");
var createApolloClient = function createApolloClient(_ref) {
  var uri = _ref.uri;
  return new _apolloClient.default({
    link: _apolloLink.ApolloLink.from([
    /**
     * This will process links from plugins on every request.
     */
    new _ApolloDynamicLink.ApolloDynamicLink(),
    /**
     * This batches requests made to the API to pack multiple requests into a single HTTP request.
     */
    new _apolloLinkBatchHttp.BatchHttpLink({
      uri: uri
    })]),
    cache: new _InMemoryCache.InMemoryCache({
      addTypename: true,
      dataIdFromObject: function dataIdFromObject(obj) {
        /**
         * Since every data type coming from API can have a different data structure,
         * we cannot rely on having an `id` field.
         */
        var getters = _plugins.plugins.byType(_ApolloCacheObjectIdPlugin.ApolloCacheObjectIdPlugin.type);
        for (var i = 0; i < getters.length; i++) {
          var id = getters[i].getObjectId(obj);
          if (typeof id !== "undefined") {
            return id;
          }
        }

        /**
         * As a fallback, try getting object's `id`.
         */
        return obj.id || null;
      }
    })
  });
};
exports.createApolloClient = createApolloClient;